@@ -126,7 +126,7 @@ class CloneHelper:
                 button.append(
                     [
                         pyrogram.InlineKeyboardButton(
-                            text="💡 𝐈𝐧𝐝𝐞𝐱 𝐋𝐢𝐧𝐤", url=f"{tam_link}"
+                            text="Index URL", url=f"{tam_link}"
                         )
                     ]
                 )
