@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # (c) Shrimadhav U K | gautamajay52
-
+ 
 import asyncio
 import logging
 import os
@@ -11,7 +11,7 @@ import subprocess
 import time
 from functools import partial
 from pathlib import Path
-
+ 
 import pyrogram.types as pyrogram
 import requests
 from hachoir.metadata import extractMetadata
@@ -20,8 +20,7 @@ from hurry.filesize import size
 from PIL import Image
 from pyrogram.errors import FloodWait, MessageNotModified
 from pyrogram.types import InlineKeyboardButton, InlineKeyboardMarkup, Message
-from pyrogram.types import InputMediaAudio, InputMediaDocument, 
-from pyrogram.types import CallbackQuery
+from pyrogram.types import InputMediaAudio, InputMediaDocument, InputMediaVideo
 from requests.utils import requote_uri
 from tgtlg import (
     DESTINATION_FOLDER,
@@ -34,14 +33,12 @@ from tgtlg import (
     UPLOAD_AS_DOC,
     gDict,
 )
-from tgtlg .helper_funcs.copy_similar_file import copy_file
-from tgtlg .helper_funcs.display_progress import humanbytes, Progress
-from tgtlg .helper_funcs.help_Nekmo_ffmpeg import take_screen_shot
-from tgtlg .helper_funcs.split_large_files import split_large_files
-
-# stackoverflow🤐
-
-
+from tgtlg.helper_funcs.copy_similar_file import copy_file
+from tgtlg.helper_funcs.display_progress import humanbytes, Progress
+from tgtlg.helper_funcs.help_Nekmo_ffmpeg import take_screen_shot
+from tgtlg.helper_funcs.split_large_files import split_large_files
+ 
+# stackoverflow
 def getFolderSize(p):
     prepend = partial(os.path.join, p)
     return sum(
@@ -50,8 +47,8 @@ def getFolderSize(p):
             for f in map(prepend, os.listdir(p))
         ]
     )
-
-
+ 
+ 
 async def upload_to_tg(
     message,
     local_file_name,
@@ -74,7 +71,7 @@ async def upload_to_tg(
         new_m_esg = message
         if not message.photo:
             new_m_esg = await message.reply_text(
-                f"Found {len(directory_contents)} files <a href='tg://user?id={update.message.from_user.id}'>{update.message.from_user.first_name}</a>",
+                f"Found {len(directory_contents)} files <a href='tg://user?id={from_user}'>!</a>",
                 quote=True
                 # reply_to_message_id=message.message_id
             )
@@ -95,8 +92,8 @@ async def upload_to_tg(
             d_f_s = humanbytes(os.path.getsize(local_file_name))
             i_m_s_g = await message.reply_text(
                 "Telegram does not support uploading this file.\n"
-                f"Detected file size: {d_f_s}\n"
-                "\ntrying to split the files"
+                f"Detected File Size: {d_f_s}\n"
+                "\nTrying to split the files.."
             )
             splitted_dir = await split_large_files(local_file_name)
             totlaa_sleif = os.listdir(splitted_dir)
@@ -105,9 +102,9 @@ async def upload_to_tg(
             LOGGER.info(totlaa_sleif)
             ba_se_file_name = os.path.basename(local_file_name)
             await i_m_s_g.edit_text(
-                f"Detected file size: {d_f_s}\n"
+                f"Detected File Size: {d_f_s}\n"
                 f"<code>{ba_se_file_name}</code> splitted into {number_of_files} files.\n"
-                "trying to upload to Telegram"
+                "Trying to upload to Telegram, now.."
             )
             for le_file in totlaa_sleif:
                 # recursion: will this FAIL somewhere?
@@ -139,15 +136,15 @@ async def upload_to_tg(
                 return
     # await message.delete()
     return dict_contatining_uploaded_files
-
-
-# © gautamajay52 thanks to Rclone team for this wonderful tool.🧘
-
-
+ 
+ 
+# © gautamajay52 thanks to Rclone team for this wonderful tool.
+ 
+ 
 async def upload_to_gdrive(file_upload, message, messa_ge, g_id):
     await asyncio.sleep(EDIT_SLEEP_TIME_OUT)
     del_it = await message.edit_text(
-        f"<a href='tg://user?id={g_id}'>🔊</a> Uploading to Cloud.."
+        f"<a href='tg://user?id={g_id}'>🔊</a> Uploading to Drive.."
     )
     if not os.path.exists("rclone.conf"):
         with open("rclone.conf", "w+", newline="\n", encoding="utf-8") as fole:
@@ -180,7 +177,7 @@ async def upload_to_gdrive(file_upload, message, messa_ge, g_id):
         LOGGER.info(gk_file)
         with open("filter.txt", "w+", encoding="utf-8") as filter:
             print(f"+ {gk_file}\n- *", file=filter)
-
+ 
         t_a_m = [
             "rclone",
             "lsf",
@@ -204,8 +201,7 @@ async def upload_to_gdrive(file_upload, message, messa_ge, g_id):
         gjay = size(os.path.getsize(file_upload))
         button = []
         button.append(
-            [pyrogram.InlineKeyboardButton(
-                text="Cloud URL", url=f"{gauti}")]
+            [pyrogram.InlineKeyboardButton(text="Cloud URL", url=f"{gauti}")]
         )
         if INDEX_LINK:
             indexurl = f"{INDEX_LINK}/{os.path.basename(file_upload)}"
@@ -221,7 +217,7 @@ async def upload_to_gdrive(file_upload, message, messa_ge, g_id):
         button_markup = pyrogram.InlineKeyboardMarkup(button)
         await asyncio.sleep(EDIT_SLEEP_TIME_OUT)
         await messa_ge.reply_text(
-            f"Uploaded successfully `{os.path.basename(file_upload)}` <a href='tg://user?id={update.message.from_user.id}'>{update.message.from_user.first_name}</a>\n Size: {gjay}",
+            f"Uploaded successfully `{os.path.basename(file_upload)}` <a href='tg://user?id={g_id}'>!</a>\n Size: {gjay}",
             reply_markup=button_markup,
         )
         os.remove(file_upload)
@@ -248,7 +244,7 @@ async def upload_to_gdrive(file_upload, message, messa_ge, g_id):
         LOGGER.info(g_file)
         with open("filter1.txt", "w+", encoding="utf-8") as filter1:
             print(f"+ {g_file}/\n- *", file=filter1)
-
+ 
         g_a_u = [
             "rclone",
             "lsf",
@@ -273,8 +269,7 @@ async def upload_to_gdrive(file_upload, message, messa_ge, g_id):
         LOGGER.info(gjay)
         button = []
         button.append(
-            [pyrogram.InlineKeyboardButton(
-                text="Cloud URL", url=f"{gautii}")]
+            [pyrogram.InlineKeyboardButton(text="Cloud URL", url=f"{gautii}")]
         )
         if INDEX_LINK:
             indexurl = f"{INDEX_LINK}/{os.path.basename(file_upload)}/"
@@ -283,23 +278,23 @@ async def upload_to_gdrive(file_upload, message, messa_ge, g_id):
             button.append(
                 [
                     pyrogram.InlineKeyboardButton(
-                        text="Index URL", url=f"{tam_link}"
+                        text="ℹ️ IndexUrl ℹ️", url=f"{tam_link}"
                     )
                 ]
             )
         button_markup = pyrogram.InlineKeyboardMarkup(button)
         await asyncio.sleep(EDIT_SLEEP_TIME_OUT)
         await messa_ge.reply_text(
-            f"Uploaded successfully `{os.path.basename(file_upload)}` <a href='tg://user?id={update.message.from_user.id}'>{update.message.from_user.first_name}</a>\n Size: {gjay}",
+            f"Uploaded successfully `{os.path.basename(file_upload)}` <a href='tg://user?id={g_id}'>!</a>\nSize: {gjay}",
             reply_markup=button_markup,
         )
         shutil.rmtree(file_upload)
         await del_it.delete()
-
-
+ 
+ 
 #
-
-
+ 
+ 
 async def upload_single_file(
     message, local_file_name, caption_str, from_user, client, edit_media, yt_thumb
 ):
@@ -312,22 +307,20 @@ async def upload_single_file(
         DOWNLOAD_LOCATION, "thumbnails", str(from_user) + ".jpg"
     )
     # LOGGER.info(thumbnail_location)
-    if UPLOAD_AS_DOC.upper() == "TRUE":  # todo: this code will be removed in future
+    if UPLOAD_AS_DOC.upper() == "TRUE":  # todo
         thumb = None
         thumb_image_path = None
         if os.path.exists(thumbnail_location):
             thumb_image_path = await copy_file(
-                thumbnail_location, os.path.dirname(
-                    os.path.abspath(local_file_name))
+                thumbnail_location, os.path.dirname(os.path.abspath(local_file_name))
             )
             thumb = thumb_image_path
         message_for_progress_display = message
         if not edit_media:
             message_for_progress_display = await message.reply_text(
-                "starting upload of {}".format(
-                    os.path.basename(local_file_name))
+                "<b>Trying to upload</b>\n\n<b> File Name</b>: <code>{}</code>".format(os.path.basename(local_file_name))
             )
-        prog = Progress(from_user, client, message_for_progress_display)
+            prog = Progress(from_user, client, message_for_progress_display)
         sent_message = await message.reply_document(
             document=local_file_name,
             thumb=thumb,
@@ -336,12 +329,10 @@ async def upload_single_file(
             disable_notification=True,
             progress=prog.progress_for_pyrogram,
             progress_args=(
-                f"{os.path.basename(local_file_name)}",
+                "",
                 start_time,
             ),
         )
-        if edit_media:
-            await message_for_progress_display.delete()
         if message.message_id != message_for_progress_display.message_id:
             try:
                 await message_for_progress_display.delete()
@@ -357,11 +348,9 @@ async def upload_single_file(
             message_for_progress_display = message
             if not edit_media:
                 message_for_progress_display = await message.reply_text(
-                    "starting upload of {}".format(
-                        os.path.basename(local_file_name))
+                    "<b>Trying to upload</b>\n\n<b> File Name</b>: <code>{}</code>".format(os.path.basename(local_file_name))
                 )
-                prog = Progress(from_user, client,
-                                message_for_progress_display)
+                prog = Progress(from_user, client, message_for_progress_display)
             if local_file_name.upper().endswith(("MKV", "MP4", "WEBM")):
                 duration = 0
                 try:
@@ -397,8 +386,7 @@ async def upload_single_file(
                         img.save(thumb_image_path, format="jpeg")
                     # get the correct width, height, and duration for videos greater than 10MB
                     if os.path.exists(thumb_image_path):
-                        metadata = extractMetadata(
-                            createParser(thumb_image_path))
+                        metadata = extractMetadata(createParser(thumb_image_path))
                         if metadata.has("width"):
                             width = metadata.get("width")
                         if metadata.has("height"):
@@ -446,7 +434,7 @@ async def upload_single_file(
                         disable_notification=True,
                         progress=prog.progress_for_pyrogram,
                         progress_args=(
-                            f"{os.path.basename(local_file_name)}",
+                            "",
                             start_time,
                         ),
                     )
@@ -498,7 +486,7 @@ async def upload_single_file(
                         disable_notification=True,
                         progress=prog.progress_for_pyrogram,
                         progress_args=(
-                            f"{os.path.basename(local_file_name)}",
+                            "",
                             start_time,
                         ),
                     )
@@ -536,13 +524,13 @@ async def upload_single_file(
                         disable_notification=True,
                         progress=prog.progress_for_pyrogram,
                         progress_args=(
-                            f"{os.path.basename(local_file_name)}",
+                            "",
                             start_time,
                         ),
                     )
                 if thumb is not None:
                     os.remove(thumb)
-
+ 
         except MessageNotModified as oY:
             LOGGER.info(oY)
         except FloodWait as g:
@@ -550,7 +538,7 @@ async def upload_single_file(
             time.sleep(g.x)
         except Exception as e:
             LOGGER.info(e)
-            await message_for_progress_display.edit_text("**FAILED**\n" + str(e))
+            await message_for_progress_display.edit_text("**Failed.**\n" + str(e))
         else:
             if message.message_id != message_for_progress_display.message_id:
                 try:
