@@ -75,7 +75,7 @@ async def status_message_f(client, message):
         # LOGGER.info(msg)
 
         if msg == "":
-            msg = "No Active, Queued or Paused TORRENTs"
+            msg = "No Active, Queued or Paused Torrents"
 
     hr, mi, se = up_time(time.time() - BOT_START_TIME)
     total, used, free = shutil.disk_usage(".")
@@ -84,7 +84,7 @@ async def status_message_f(client, message):
     free = humanbytes(free)
 
     ms_g = (
-        f"<b>Bot Uptime</b>: <code>{hr} : {mi} : {se}</code>\n"
+        f"<b>Bot Uptime</b>: <code>{hr}h {mi}min {se}sec</code>\n"
         f"<b>Total disk space</b>: <code>{total}</code>\n"
         f"<b>Used</b>: <code>{used}</code>\n"
         f"<b>Free</b>: <code>{free}</code>\n"
